@@ -453,6 +453,8 @@ static int
 wireless_applet_timeout_handler (WirelessApplet *applet)
 {
 	if (applet->file == NULL) {
+		wireless_applet_update_state (applet,
+				applet->device, -1, -1, -1);
 		return FALSE;
 	}
 
@@ -475,6 +477,7 @@ show_error_dialog (gchar *mesg,...)
 			0, GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE,
 			mesg, NULL);
 	gtk_dialog_run (GTK_DIALOG (dialog));
+	gtk_widget_destroy (dialog);
 	g_free (tmp);
 	va_end (ap);
 }
@@ -492,6 +495,7 @@ show_warning_dialog (gchar *mesg,...)
 			0, GTK_MESSAGE_WARNING, GTK_BUTTONS_CLOSE,
 			mesg, NULL);
 	gtk_dialog_run (GTK_DIALOG (dialog));
+	gtk_widget_destroy (dialog);
 	g_free (tmp);
 	va_end (ap);
 }
@@ -510,6 +514,7 @@ show_message_dialog (char *mesg,...)
 			0, GTK_MESSAGE_INFO, GTK_BUTTONS_CLOSE,
 			mesg, NULL);
 	gtk_dialog_run (GTK_DIALOG (dialog));
+	gtk_widget_destroy (dialog);
 	g_free (tmp);
 	va_end (ap);
 }
@@ -551,7 +556,8 @@ wireless_applet_load_properties (WirelessApplet *applet)
 static void
 wireless_applet_save_properties (WirelessApplet *applet)
 {
-	panel_applet_gconf_set_string (PANEL_APPLET (applet),
+	if (applet->device)
+		panel_applet_gconf_set_string (PANEL_APPLET (applet),
 			"device", applet->device, NULL);
 	panel_applet_gconf_set_bool (PANEL_APPLET (applet),
 			"percent", applet->show_percent, NULL);
@@ -563,7 +569,7 @@ static void
 wireless_applet_option_change (GtkWidget *widget, gpointer user_data)
 {
 	GtkWidget *entry;
-	GtkWidget *menu;
+	GtkWidget *menu = NULL;
 	char *str;
 	WirelessApplet *applet = (WirelessApplet *)user_data;
 
@@ -581,10 +587,13 @@ wireless_applet_option_change (GtkWidget *widget, gpointer user_data)
 			(GTK_TOGGLE_BUTTON (entry)));
 
 	entry = g_object_get_data (G_OBJECT (applet->prefs), "device-menu");
+
 	menu = gtk_menu_get_active
 		(GTK_MENU (gtk_option_menu_get_menu (GTK_OPTION_MENU (entry))));
-	str = g_object_get_data (G_OBJECT (menu), "device-selected");
-	wireless_applet_set_device (applet, str);
+	if (menu) {
+		str = g_object_get_data (G_OBJECT (menu), "device-selected");
+		wireless_applet_set_device (applet, str);
+	}
 
 	/* Save the properties */
 	wireless_applet_save_properties (applet);
@@ -668,6 +677,20 @@ wireless_applet_properties_dialog (BonoboUIComponent *uic,
 			}
 			idx++;
 		}
+		if (applet->devices == NULL) {
+			char *markup;
+			GtkWidget *label;
+			
+			label = gtk_label_new (NULL);
+			markup = g_strdup_printf ("<i>%s</i>",
+					_("No Wireless Devices"));
+			gtk_label_set_markup (GTK_LABEL (label), markup);
+			g_free (markup);
+
+			item = gtk_menu_item_new ();
+			gtk_container_add (GTK_CONTAINER (item), label);
+			gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
+		}
 		gtk_option_menu_set_menu (GTK_OPTION_MENU (device), menu);
 		gtk_option_menu_set_history (GTK_OPTION_MENU (device), choice);
 	}
@@ -738,7 +761,7 @@ static void
 wireless_applet_destroy (WirelessApplet *applet, gpointer horse)
 {
 	g_free (applet->device);
-	
+
 	g_list_foreach (applet->no_link_images, (GFunc)g_free, NULL);
 	g_list_free (applet->no_link_images);
 
@@ -766,7 +789,8 @@ wireless_applet_destroy (WirelessApplet *applet, gpointer horse)
 		applet->prefs = NULL;
 	}
 
-	fclose (applet->file);
+	if (applet->file)
+		fclose (applet->file);
 }
 
 static GtkWidget *
